@@ -38,6 +38,7 @@ async def create_run(request: ApiRequest):
             thread_id,
             payload,
             request.headers,
+            request_start_time=request.scope.get("request_start_time_ms"),
         )
     return ApiResponse(
         run,
@@ -55,6 +56,7 @@ async def create_stateless_run(request: ApiRequest):
             None,
             payload,
             request.headers,
+            request_start_time=request.scope.get("request_start_time_ms"),
         )
     return ApiResponse(
         run,
@@ -75,6 +77,7 @@ async def create_stateless_run_batch(request: ApiRequest):
                 payload,
                 request.headers,
                 barrier,
+                request_start_time=request.scope.get("request_start_time_ms"),
             )
             for payload in batch_payload
         ]
@@ -100,6 +103,7 @@ async def stream_run(
                 payload,
                 request.headers,
                 run_id=run_id,
+                request_start_time=request.scope.get("request_start_time_ms"),
             )
     except Exception:
         if not sub.cancelled():
@@ -139,6 +143,7 @@ async def stream_run_stateless(
                 payload,
                 request.headers,
                 run_id=run_id,
+                request_start_time=request.scope.get("request_start_time_ms"),
             )
     except Exception:
         if not sub.cancelled():
@@ -178,6 +183,7 @@ async def wait_run(request: ApiRequest):
                 payload,
                 request.headers,
                 run_id=run_id,
+                request_start_time=request.scope.get("request_start_time_ms"),
             )
     except Exception:
         if not sub.cancelled():
@@ -216,6 +222,9 @@ async def wait_run(request: ApiRequest):
         stream = asyncio.create_task(consume())
         while True:
             try:
+                if stream.done():
+                    # raise stream exception if any
+                    stream.result()
                 yield await asyncio.wait_for(last_chunk.wait(), timeout=5)
                 break
             except TimeoutError:
@@ -250,6 +259,7 @@ async def wait_run_stateless(request: ApiRequest):
                 payload,
                 request.headers,
                 run_id=run_id,
+                request_start_time=request.scope.get("request_start_time_ms"),
             )
     except Exception:
         if not sub.cancelled():
@@ -263,7 +273,10 @@ async def wait_run_stateless(request: ApiRequest):
         vchunk: bytes | None = None
         async with aclosing(
             Runs.Stream.join(
-                run["run_id"], thread_id=run["thread_id"], stream_mode=await sub
+                run["run_id"],
+                thread_id=run["thread_id"],
+                stream_mode=await sub,
+                ignore_404=True,
             )
         ) as stream:
             async for mode, chunk, _ in stream:
@@ -283,6 +296,9 @@ async def wait_run_stateless(request: ApiRequest):
         stream = asyncio.create_task(consume())
         while True:
             try:
+                if stream.done():
+                    # raise stream exception if any
+                    stream.result()
                 yield await asyncio.wait_for(last_chunk.wait(), timeout=5)
                 break
             except TimeoutError:
