@@ -3,7 +3,6 @@ import functools
 import glob
 import importlib.util
 import inspect
-import json
 import os
 import sys
 import warnings
@@ -14,12 +13,15 @@ from random import choice
 from typing import TYPE_CHECKING, Any, NamedTuple
 from uuid import UUID, uuid5
 
+import orjson
 import structlog
-from langchain_core.runnables.config import run_in_executor
+from langchain_core.runnables.config import run_in_executor, var_child_runnable_config
 from langgraph.checkpoint.base import BaseCheckpointSaver
-from langgraph.graph import Graph
+from langgraph.constants import CONFIG_KEY_CHECKPOINTER, CONFIG_KEY_STORE
+from langgraph.graph import StateGraph
 from langgraph.pregel import Pregel
 from langgraph.store.base import BaseStore
+from langgraph.utils.config import ensure_config
 from starlette.exceptions import HTTPException
 
 from langgraph_api import asyncio as lg_asyncio
@@ -32,8 +34,8 @@ if TYPE_CHECKING:
 
 logger = structlog.stdlib.get_logger(__name__)
 
-GraphFactoryFromConfig = Callable[[Config], Pregel | Graph]
-GraphFactory = Callable[[], Pregel | Graph]
+GraphFactoryFromConfig = Callable[[Config], Pregel | StateGraph]
+GraphFactory = Callable[[], Pregel | StateGraph]
 GraphValue = Pregel | GraphFactory
 
 
@@ -58,6 +60,12 @@ async def register_graph(
     if callable(graph):
         FACTORY_ACCEPTS_CONFIG[graph_id] = len(inspect.signature(graph).parameters) > 0
     async with connect() as conn:
+        graph_name = getattr(graph, "name", None) if isinstance(graph, Pregel) else None
+        assistant_name = (
+            graph_name
+            if graph_name is not None and graph_name != "LangGraph"
+            else graph_id
+        )
         await Assistants.put(
             conn,
             str(uuid5(NAMESPACE_GRAPH, graph_id)),
@@ -65,7 +73,7 @@ async def register_graph(
             metadata={"created_by": "system"},
             config=config or {},
             if_exists="do_nothing",
-            name=graph_id,
+            name=assistant_name,
             description=description,
         )
 
@@ -109,26 +117,38 @@ async def get_graph(
     """Return the runnable."""
     assert_graph_exists(graph_id)
     value = GRAPHS[graph_id]
+    token = None
     if graph_id in FACTORY_ACCEPTS_CONFIG:
+        config = ensure_config(config)
+        if store is not None and not config["configurable"].get(CONFIG_KEY_STORE):
+            config["configurable"][CONFIG_KEY_STORE] = store
+        if checkpointer is not None and not config["configurable"].get(
+            CONFIG_KEY_CHECKPOINTER
+        ):
+            config["configurable"][CONFIG_KEY_CHECKPOINTER] = checkpointer
+        token = var_child_runnable_config.set(config)
         value = value(config) if FACTORY_ACCEPTS_CONFIG[graph_id] else value()
-
-    async with _generate_graph(value) as graph_obj:
-        if isinstance(graph_obj, Graph):
-            graph_obj = graph_obj.compile()
-        if not isinstance(graph_obj, Pregel | BaseRemotePregel):
-            raise HTTPException(
-                status_code=424,
-                detail=f"Graph '{graph_id}' is not valid. Review graph registration.",
-            )
-        update = {
-            "checkpointer": checkpointer,
-            "store": store,
-        }
-        if graph_obj.name == "LangGraph":
-            update["name"] = graph_id
-        if isinstance(graph_obj, BaseRemotePregel):
-            update["config"] = config
-        yield graph_obj.copy(update=update)
+    try:
+        async with _generate_graph(value) as graph_obj:
+            if isinstance(graph_obj, StateGraph):
+                graph_obj = graph_obj.compile()
+            if not isinstance(graph_obj, Pregel | BaseRemotePregel):
+                raise HTTPException(
+                    status_code=424,
+                    detail=f"Graph '{graph_id}' is not valid. Review graph registration.",
+                )
+            update = {
+                "checkpointer": checkpointer,
+                "store": store,
+            }
+            if graph_obj.name == "LangGraph":
+                update["name"] = graph_id
+            if isinstance(graph_obj, BaseRemotePregel):
+                update["config"] = config
+            yield graph_obj.copy(update=update)
+    finally:
+        if token is not None:
+            var_child_runnable_config.reset(token)
 
 
 def graph_exists(graph_id: str) -> bool:
@@ -186,10 +206,19 @@ def _load_graph_config_from_env() -> dict | None:
     config_str = os.getenv("LANGGRAPH_CONFIG")
     if not config_str:
         return None
+    try:
+        config_per_id = orjson.loads(config_str)
+    except orjson.JSONDecodeError as e:
+        raise ValueError(
+            "Provided environment variable LANGGRAPH_CONFIG must be a valid JSON object"
+            f"\nFound: {config_str}"
+        ) from e
 
-    config_per_id = json.loads(config_str)
     if not isinstance(config_per_id, dict):
-        raise ValueError("LANGGRAPH_CONFIG must be a JSON object")
+        raise ValueError(
+            "Provided environment variable LANGGRAPH_CONFIG must be a JSON object"
+            f"\nFound: {config_str}"
+        )
 
     return config_per_id
 
@@ -204,7 +233,15 @@ async def collect_graphs_from_env(register: bool = False) -> None:
         specs = []
         # graphs-config can be either a mapping from graph id to path where the graph
         # is defined or graph id to a dictionary containing information about the graph.
-        graphs_config = json.loads(paths_str)
+        try:
+            graphs_config = orjson.loads(paths_str)
+        except orjson.JSONDecodeError as e:
+            raise ValueError(
+                "LANGSERVE_GRAPHS must be a valid JSON object."
+                f"\nFound: {paths_str}"
+                "\n The LANGSERVE_GRAPHS environment variable is typically set"
+                'from the "graphs" field in your configuration (langgraph.json) file.'
+            ) from e
 
         for key, value in graphs_config.items():
             if isinstance(value, dict) and "path" in value:
@@ -405,7 +442,7 @@ def _graph_from_spec(spec: GraphSpec) -> GraphValue:
                 likely = [
                     k
                     for k in available
-                    if isinstance(module.__dict__[k], Graph | Pregel)
+                    if isinstance(module.__dict__[k], StateGraph | Pregel)
                 ]
                 if likely:
                     prefix = spec.module or spec.path
@@ -434,7 +471,7 @@ def _graph_from_spec(spec: GraphSpec) -> GraphValue:
                 raise ValueError(
                     f"Graph factory function '{spec.variable}' in module '{spec.path}' must take exactly one argument, a RunnableConfig"
                 )
-        elif isinstance(graph, Graph):
+        elif isinstance(graph, StateGraph):
             graph = graph.compile()
         elif isinstance(graph, Pregel):
             # We don't want to fail real deployments, but this will help folks catch unnecessary custom components
@@ -476,7 +513,7 @@ def _graph_from_spec(spec: GraphSpec) -> GraphValue:
                 break
         else:
             for _, member in inspect.getmembers(module):
-                if isinstance(member, Graph):
+                if isinstance(member, StateGraph):
                     graph = member.compile()
                     break
             else:
@@ -487,7 +524,7 @@ def _graph_from_spec(spec: GraphSpec) -> GraphValue:
     return graph
 
 
-@functools.lru_cache
+@functools.lru_cache(maxsize=1)
 def _get_init_embeddings() -> Callable[[str, ...], "Embeddings"] | None:
     try:
         from langchain.embeddings import init_embeddings
