@@ -48,7 +48,6 @@ from langgraph_api.js.sse import SSEDecoder, aiter_lines_raw
 from langgraph_api.route import ApiResponse
 from langgraph_api.schema import Config
 from langgraph_api.serde import json_dumpb
-from langgraph_api.utils import AsyncConnectionProto
 
 logger = structlog.stdlib.get_logger(__name__)
 
@@ -452,27 +451,27 @@ async def run_js_http_process(paths_str: str, http_config: dict, watch: bool = F
                 attempt += 1
 
 
-def _get_passthrough_checkpointer(conn: AsyncConnectionProto):
+class PassthroughSerialiser(SerializerProtocol):
+    def dumps(self, obj: Any) -> bytes:
+        return json_dumpb(obj)
+
+    def dumps_typed(self, obj: Any) -> tuple[str, bytes]:
+        return "json", json_dumpb(obj)
+
+    def loads(self, data: bytes) -> Any:
+        return orjson.loads(data)
+
+    def loads_typed(self, data: tuple[str, bytes]) -> Any:
+        type, payload = data
+        if type != "json":
+            raise ValueError(f"Unsupported type {type}")
+        return orjson.loads(payload)
+
+
+def _get_passthrough_checkpointer():
     from langgraph_runtime.checkpoint import Checkpointer
 
-    class PassthroughSerialiser(SerializerProtocol):
-        def dumps(self, obj: Any) -> bytes:
-            return json_dumpb(obj)
-
-        def dumps_typed(self, obj: Any) -> tuple[str, bytes]:
-            return "json", json_dumpb(obj)
-
-        def loads(self, data: bytes) -> Any:
-            return orjson.loads(data)
-
-        def loads_typed(self, data: tuple[str, bytes]) -> Any:
-            type, payload = data
-            if type != "json":
-                raise ValueError(f"Unsupported type {type}")
-            return orjson.loads(payload)
-
-    checkpointer = Checkpointer(conn)
-
+    checkpointer = Checkpointer()
     # This checkpointer does not attempt to revive LC-objects.
     # Instead, it will pass through the JSON values as-is.
     checkpointer.serde = PassthroughSerialiser()
@@ -487,53 +486,46 @@ async def _get_passthrough_store():
 # Setup a HTTP server on top of CHECKPOINTER_SOCKET unix socket
 # used by `client.mts` to communicate with the Python checkpointer
 async def run_remote_checkpointer():
-    from langgraph_runtime.database import connect
-
     async def checkpointer_list(payload: dict):
         """Search checkpoints"""
 
         result = []
-        async with connect() as conn:
-            checkpointer = _get_passthrough_checkpointer(conn)
-            async for item in checkpointer.alist(
-                config=payload.get("config"),
-                limit=int(payload.get("limit") or 10),
-                before=payload.get("before"),
-                filter=payload.get("filter"),
-            ):
-                result.append(item)
+        checkpointer = _get_passthrough_checkpointer()
+        async for item in checkpointer.alist(
+            config=payload.get("config"),
+            limit=int(payload.get("limit") or 10),
+            before=payload.get("before"),
+            filter=payload.get("filter"),
+        ):
+            result.append(item)
 
         return result
 
     async def checkpointer_put(payload: dict):
         """Put the new checkpoint metadata"""
 
-        async with connect() as conn:
-            checkpointer = _get_passthrough_checkpointer(conn)
-            return await checkpointer.aput(
-                payload["config"],
-                payload["checkpoint"],
-                payload["metadata"],
-                payload.get("new_versions", {}),
-            )
+        checkpointer = _get_passthrough_checkpointer()
+        return await checkpointer.aput(
+            payload["config"],
+            payload["checkpoint"],
+            payload["metadata"],
+            payload.get("new_versions", {}),
+        )
 
     async def checkpointer_get_tuple(payload: dict):
         """Get actual checkpoint values (reads)"""
-
-        async with connect() as conn:
-            checkpointer = _get_passthrough_checkpointer(conn)
-            return await checkpointer.aget_tuple(config=payload["config"])
+        checkpointer = _get_passthrough_checkpointer()
+        return await checkpointer.aget_tuple(config=payload["config"])
 
     async def checkpointer_put_writes(payload: dict):
         """Put actual checkpoint values (writes)"""
 
-        async with connect() as conn:
-            checkpointer = _get_passthrough_checkpointer(conn)
-            return await checkpointer.aput_writes(
-                payload["config"],
-                payload["writes"],
-                payload["taskId"],
-            )
+        checkpointer = _get_passthrough_checkpointer()
+        return await checkpointer.aput_writes(
+            payload["config"],
+            payload["writes"],
+            payload["taskId"],
+        )
 
     async def store_batch(payload: dict):
         """Batch operations on the store"""
@@ -687,7 +679,11 @@ async def run_remote_checkpointer():
                 payload = orjson.loads(await request.body())
                 return ApiResponse(await cb(payload))
             except ValueError as exc:
+                await logger.error(exc)
                 return ApiResponse({"error": str(exc)}, status_code=400)
+            except Exception as exc:
+                await logger.error(exc)
+                return ApiResponse({"error": str(exc)}, status_code=500)
 
         return wrapped
 
@@ -800,15 +796,18 @@ async def js_healthcheck():
                 transport=httpx.AsyncHTTPTransport(verify=SSL),
             ) as checkpointer_client,
         ):
+            graph_passed = False
             try:
                 res = await graph_client.get("/ok")
                 res.raise_for_status()
+                graph_passed = True
                 res = await checkpointer_client.get("/ok")
                 res.raise_for_status()
                 return True
             except httpx.HTTPError as exc:
                 logger.warning(
                     "JS healthcheck failed. Either the JS server is not running or the event loop is blocked by a CPU-intensive task.",
+                    graph_passed=graph_passed,
                     error=exc,
                 )
                 raise HTTPException(
