@@ -57,6 +57,16 @@ class AddPrefixedEnvVars:
         return event_dict
 
 
+class AddApiVersion:
+    def __call__(
+        self, logger: logging.Logger, method_name: str, event_dict: EventDict
+    ) -> EventDict:
+        from langgraph_api import __version__
+
+        event_dict["langgraph_api_version"] = __version__
+        return event_dict
+
+
 class AddLoggingContext:
     def __call__(
         self, logger: logging.Logger, method_name: str, event_dict: EventDict
@@ -81,23 +91,6 @@ class JSONRenderer:
 LEVELS = logging.getLevelNamesMapping()
 
 
-class TapForMetadata:
-    def __call__(
-        self, logger: logging.Logger, method_name: str, event_dict: EventDict
-    ) -> str:
-        """
-        Tap WARN and above logs for metadata. Exclude user loggers.
-        """
-        if (
-            event_dict["logger"].startswith("langgraph")
-            and LEVELS[event_dict["level"].upper()] > LEVELS["INFO"]
-        ):
-            from langgraph_api.metadata import append_log
-
-            append_log(event_dict.copy())
-        return event_dict
-
-
 # shared config, for both logging and structlog
 
 shared_processors = [
@@ -107,11 +100,14 @@ shared_processors = [
     structlog.stdlib.PositionalArgumentsFormatter(),
     structlog.stdlib.ExtraAdder(),
     AddPrefixedEnvVars("LANGSMITH_LANGGRAPH_"),  # injected by docker build
+    AddApiVersion(),
     structlog.processors.TimeStamper(fmt="iso", utc=True),
     structlog.processors.StackInfoRenderer(),
-    structlog.processors.dict_tracebacks
-    if LOG_JSON
-    else structlog.processors.format_exc_info,
+    (
+        structlog.processors.dict_tracebacks
+        if LOG_JSON
+        else structlog.processors.format_exc_info
+    ),
     structlog.processors.UnicodeDecoder(),
     AddLoggingContext(),
 ]
@@ -136,7 +132,6 @@ class Formatter(structlog.stdlib.ProcessorFormatter):
         super().__init__(
             processors=[
                 structlog.stdlib.ProcessorFormatter.remove_processors_meta,
-                TapForMetadata(),
                 renderer,
             ],
             foreign_pre_chain=shared_processors,
