@@ -1,5 +1,5 @@
 from collections.abc import AsyncIterator, Callable
-from contextlib import AsyncExitStack, aclosing
+from contextlib import AsyncExitStack, aclosing, asynccontextmanager
 from functools import lru_cache
 from typing import Any, cast
 
@@ -20,6 +20,7 @@ from langgraph.errors import (
     InvalidUpdateError,
 )
 from langgraph.pregel.debug import CheckpointPayload, TaskResultPayload
+from langsmith.utils import get_tracer_project
 from pydantic import ValidationError
 from pydantic.v1 import ValidationError as ValidationErrorLegacy
 
@@ -31,7 +32,6 @@ from langgraph_api.js.base import BaseRemotePregel
 from langgraph_api.metadata import HOST, PLAN, USER_API_URL, incr_nodes
 from langgraph_api.schema import Run, StreamMode
 from langgraph_api.serde import json_dumpb
-from langgraph_api.utils import AsyncConnectionProto
 from langgraph_runtime.checkpoint import Checkpointer
 from langgraph_runtime.ops import Runs
 
@@ -71,9 +71,13 @@ def _preprocess_debug_checkpoint(payload: CheckpointPayload | None) -> dict[str,
     return payload
 
 
+@asynccontextmanager
+async def async_tracing_context(*args, **kwargs):
+    with langsmith.tracing_context(*args, **kwargs):
+        yield
+
+
 async def astream_state(
-    stack: AsyncExitStack,
-    conn: AsyncConnectionProto,
     run: Run,
     attempt: int,
     done: ValueEvent,
@@ -83,7 +87,6 @@ async def astream_state(
 ) -> AnyStream:
     """Stream messages from the runnable."""
     run_id = str(run["run_id"])
-    await stack.enter_async_context(conn.pipeline())
     # extract args from run
     kwargs = run["kwargs"].copy()
     kwargs.pop("webhook", None)
@@ -91,12 +94,13 @@ async def astream_state(
     subgraphs = kwargs.get("subgraphs", False)
     temporary = kwargs.pop("temporary", False)
     config = kwargs.pop("config")
+    stack = AsyncExitStack()
     graph = await stack.enter_async_context(
         get_graph(
             config["configurable"]["graph_id"],
             config,
             store=(await api_store.get_store()),
-            checkpointer=None if temporary else Checkpointer(conn),
+            checkpointer=None if temporary else Checkpointer(),
         )
     )
     input = kwargs.pop("input")
@@ -131,6 +135,25 @@ async def astream_state(
     use_astream_events = "events" in stream_mode or isinstance(graph, BaseRemotePregel)
     # yield metadata chunk
     yield "metadata", {"run_id": run_id, "attempt": attempt}
+
+    #  is a langsmith tracing project is specified, additionally pass that in to tracing context
+    if ls_project := config["configurable"].get("__langsmith_project__"):
+        updates = None
+        if example_id := config["configurable"].get("__langsmith_example_id__"):
+            updates = {"reference_example_id": example_id}
+
+        await stack.enter_async_context(
+            async_tracing_context(
+                replicas=[
+                    (
+                        ls_project,
+                        updates,
+                    ),
+                    (get_tracer_project(), None),
+                ]
+            )
+        )
+
     # stream run
     if use_astream_events:
         async with (
@@ -207,11 +230,16 @@ async def astream_state(
                 elif "events" in stream_mode:
                     yield "events", event
     else:
+        output_keys = kwargs.pop("output_keys", graph.output_channels)
         async with (
             stack,
             aclosing(
                 graph.astream(
-                    input, config, stream_mode=list(stream_modes_set), **kwargs
+                    input,
+                    config,
+                    stream_mode=list(stream_modes_set),
+                    output_keys=output_keys,
+                    **kwargs,
                 )
             ) as stream,
         ):
@@ -264,7 +292,7 @@ async def astream_state(
                         yield mode, chunk
                 # --- end shared logic with astream_events ---
     if is_remote_pregel:
-        # increament the remote runs
+        # increment the remote runs
         try:
             nodes_executed = await graph.fetch_nodes_executed()
             incr_nodes(None, incr=nodes_executed)
